"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var flows_1 = require("@ice/dike-core-js/lib/types/flows");
var date_fns_1 = require("date-fns");
var electron_1 = require("electron");
var fs = require("fs");
var lodash_1 = require("lodash");
var path = require("path");
var uuid_1 = require("uuid");
var dikeClients_1 = require("../dikeClients");
var FSM_1 = require("../FSM");
var genericFsm_1 = require("../FSM/genericFsm");
var logger_1 = require("../logger");
var model_1 = require("../model");
var DikeErrors_1 = require("../shared/DikeErrors");
var request_1 = require("../shared/request");
var logger = logger_1.provideLogger('VerificationHandlers');
var assert = require('assert').strict;
var FLOW_TYPE = flows_1.FlowType.DGS_FLOW_VERIFY;
var VerificationFsmChannelInit = /** @class */ (function () {
    function VerificationFsmChannelInit() {
    }
    VerificationFsmChannelInit.prototype.handleRequest = function (body) {
        logger.info('Init verification fsm');
        var genericFsm = genericFsm_1.GenericFsm.of(FLOW_TYPE, dikeClients_1.DikeClients.getInstance());
        genericFsm_1.FsmRegistry.getInstance().set(FLOW_TYPE, genericFsm);
        return genericFsm.init().then(function () {
            return genericFsm.nextState().then(function (v) { return FSM_1.fromState(v); });
        });
    };
    return VerificationFsmChannelInit;
}());
exports.VerificationFsmChannelInit = VerificationFsmChannelInit;
var VerificationFsmChannelVerify = /** @class */ (function () {
    function VerificationFsmChannelVerify(analyticsEventHandler) {
        this.analyticsEventHandler = analyticsEventHandler;
    }
    VerificationFsmChannelVerify.prototype.handleRequest = function (body) {
        var _this = this;
        logger.info('Performing verification %s', JSON.stringify(body));
        var payload = {
            files: body.files,
            check_revocation: true,
            verify_date: date_fns_1.format(new Date(), "yyyyMMdd'T'HHmmss'Z'"),
        };
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        return genericFsm
            .send(flows_1.FlowEvent.DGS_EVT_VERIFY_PARAMS_INSERTED, payload)
            .then(function (value) {
            if (value.state_type === flows_1.FlowStateType.DGS_STATE_VERIFY_DONE) {
                var state = value.state_data;
                var count = state.results.length;
                _this.analyticsEventHandler.sendVerification(count);
            }
            ;
            return FSM_1.fromState(value);
        });
    };
    return VerificationFsmChannelVerify;
}());
exports.VerificationFsmChannelVerify = VerificationFsmChannelVerify;
var VerificationFsmChannelTslAdded = /** @class */ (function () {
    function VerificationFsmChannelTslAdded() {
    }
    VerificationFsmChannelTslAdded.prototype.handleRequest = function (body) {
        logger.info('Adding missing TSL %s', JSON.stringify(body.countries));
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        var payload = {
            countries_tsl: body.countries,
        };
        return genericFsm
            .send(flows_1.FlowEvent.DGS_EVT_VERIFY_ADD_COUNTRY_TSL, payload)
            .then(function (value) { return FSM_1.fromState(value); });
    };
    return VerificationFsmChannelTslAdded;
}());
exports.VerificationFsmChannelTslAdded = VerificationFsmChannelTslAdded;
var VerificationFsmChannelDetachedSourcesPassed = /** @class */ (function () {
    function VerificationFsmChannelDetachedSourcesPassed() {
    }
    VerificationFsmChannelDetachedSourcesPassed.prototype.handleRequest = function (body) {
        logger.info('Passing detached sources %s', JSON.stringify(body.sources));
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        var payload = request_1.mapToVerifyDetachedSources(body);
        return genericFsm
            .send(flows_1.FlowEvent.DGS_EVT_VERIFY_DETACHED_SOURCES, payload)
            .then(function (value) { return FSM_1.fromState(value); });
    };
    return VerificationFsmChannelDetachedSourcesPassed;
}());
exports.VerificationFsmChannelDetachedSourcesPassed = VerificationFsmChannelDetachedSourcesPassed;
var VerificationFsmChannelOpenReport = /** @class */ (function () {
    function VerificationFsmChannelOpenReport() {
    }
    VerificationFsmChannelOpenReport.prototype.handleRequest = function (body) {
        logger.info("Opening report request %s", JSON.stringify(body));
        var core = dikeClients_1.DikeClients.getInstance();
        try {
            var temp = electron_1.app.getPath('temp');
            assert(!lodash_1.isNil(temp), 'Cannot determine temp folder');
            var filename = uuid_1.v4() + ".html";
            var tmpPath_1 = path.join(temp, filename);
            logger.info("Storing report file in " + temp);
            var atDateFmt = undefined;
            if (!lodash_1.isNil(body.atDate)) {
                atDateFmt = date_fns_1.format(new Date(body.atDate), "yyMMddHHmmss");
            }
            logger.info("At date " + atDateFmt);
            return core.createHTMLverificationReport(body.filePath, tmpPath_1, body.dataFile, atDateFmt).then(function () { return electron_1.shell.openItem(tmpPath_1); });
        }
        catch (e) {
            return Promise.reject(model_1.DikeError.of(DikeErrors_1.DikeErrors.CANNOT_STORE_TEMP, e.message));
        }
    };
    return VerificationFsmChannelOpenReport;
}());
exports.VerificationFsmChannelOpenReport = VerificationFsmChannelOpenReport;
var VerificationAbortChannel = /** @class */ (function () {
    function VerificationAbortChannel() {
    }
    VerificationAbortChannel.prototype.handleRequest = function (body) {
        var genericFsm = genericFsm_1.FsmRegistry.getInstance().get(FLOW_TYPE);
        return genericFsm.flow.abort().then(function (value) { return (!value ? {} : value); });
    };
    return VerificationAbortChannel;
}());
exports.VerificationAbortChannel = VerificationAbortChannel;
var VerificationPerformAtDateChannel = /** @class */ (function () {
    function VerificationPerformAtDateChannel() {
    }
    VerificationPerformAtDateChannel.prototype.handleRequest = function (body) {
        logger.info('Performing verification at date %s', JSON.stringify(body));
        var datafile = body.detachedFilePath ? body.detachedFilePath : '';
        var verifydate = body.atDate ? body.atDate : '';
        return dikeClients_1.DikeClients.getInstance().verifyFile(body.inputFilePath, datafile, verifydate)
            // TODO: akokot: remove when core library updated
            .then(function (result) { return result; });
    };
    return VerificationPerformAtDateChannel;
}());
exports.VerificationPerformAtDateChannel = VerificationPerformAtDateChannel;
var VerificationExtractHandler = /** @class */ (function () {
    function VerificationExtractHandler(logger) {
        this.logger = logger;
    }
    VerificationExtractHandler.prototype.handleRequest = function (body) {
        this.logger.info("Extract %s", body);
        var filename = path.parse(body.inputFile);
        var folderName = "verification_" + date_fns_1.format(new Date(), "yyMMddHHmmssSSS");
        var tempFolder = lodash_1.cond([
            [function (t) { return t; }, function () { return electron_1.app.getPath('temp'); }],
            [lodash_1.stubTrue, function () { return body.outputFolder; }]
        ])(body.useTemp);
        var extractionFolder = path.join(tempFolder, folderName);
        return this.extract({
            folderName: folderName,
            inputFile: body.inputFile,
            outputFolder: extractionFolder,
            openFirst: body.tryOpenFirstOutput,
            dotExtractedFullPath: extractionFolder
        });
    };
    VerificationExtractHandler.prototype.extract = function (extractArguments) {
        var _this = this;
        this.logger.info("Extracting %s", JSON.stringify(extractArguments));
        return dikeClients_1.DikeClients.getInstance().extractFile(extractArguments.inputFile, extractArguments.outputFolder)
            .then(function (arg) {
            _this.logger.info("ApiResult is " + JSON.stringify(arg));
            var isOpenFirst = function (a) { return a.openFirst; };
            return lodash_1.cond([
                [isOpenFirst, function (a) { return _this.tryOpenFirst(a.dotExtractedFullPath); }],
                [lodash_1.stubTrue, function (a) {
                        electron_1.shell.showItemInFolder(a.dotExtractedFullPath);
                        return { status: 'ok' };
                    }]
            ])(extractArguments);
        });
    };
    /**
     * Try open the first extracted files from dotExtractedFullPath,
     * if path does not exists trhrow an error, if file cannot be opened
     * the paret folder is shown istead
     * @param dotExtractedFullPath
     * @private
     */
    VerificationExtractHandler.prototype.tryOpenFirst = function (dotExtractedFullPath) {
        this.logger.info("Try open first " + dotExtractedFullPath);
        var files = fs.readdirSync(dotExtractedFullPath);
        var firstOutput = lodash_1.get(files, '0', dotExtractedFullPath);
        if (!electron_1.shell.openItem(path.join(dotExtractedFullPath, firstOutput))) {
            this.logger.warn("cannot open " + firstOutput + ", open his parent path " + dotExtractedFullPath + " instead");
            electron_1.shell.showItemInFolder(dotExtractedFullPath);
            return { status: 'ok' };
        }
        return { status: 'ok' };
    };
    return VerificationExtractHandler;
}());
exports.VerificationExtractHandler = VerificationExtractHandler;
var VerificationExtractFilesHandler = /** @class */ (function () {
    function VerificationExtractFilesHandler(logger) {
        this.logger = logger;
    }
    VerificationExtractFilesHandler.prototype.handleRequest = function (body) {
        this.logger.info("Extract %s", body);
        var extractionFolder = body.json.output_dirs[0];
        var json = {
            output_dirs: body.json.output_dirs,
            input_files: body.json.input_files
        };
        return this.extractFiles({
            dotExtractedFullPath: extractionFolder,
            json: json
        });
    };
    VerificationExtractFilesHandler.prototype.extractFiles = function (extractArguments) {
        var _this = this;
        this.logger.info("Extracting %s", JSON.stringify(extractArguments));
        //@ts-ignore
        return dikeClients_1.DikeClients.getInstance().extractFiles(extractArguments.json)
            .then(function (arg) {
            _this.logger.info("ApiResult is " + JSON.stringify(arg));
            return lodash_1.cond([
                [lodash_1.stubTrue, function (a) {
                        electron_1.shell.showItemInFolder(a.dotExtractedFullPath);
                        return { status: 'ok' };
                    }]
            ])(extractArguments);
        });
    };
    return VerificationExtractFilesHandler;
}());
exports.VerificationExtractFilesHandler = VerificationExtractFilesHandler;
//# sourceMappingURL=VerificationHandlers.js.map